@@ -5,8 +5,7 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Package-Version: 1.10
-;; Package-Revision: 8829e48aabd2
+;; Version: 1.10
 ;; Package-Requires: ((emacs "29.1") (org "9.6") (compat "30"))
 ;; URL: https://github.com/minad/org-modern
 ;; Keywords: outlines, hypermedia, text
@@ -417,7 +416,7 @@ the font.")
        beg end 'face
        (if-let ((face (or (cdr (assq prio org-modern-priority-faces))
                           (cdr (assq t org-modern-priority-faces)))))
-           `(:inherit (,face org-modern-label))
+           `(,face org-modern-label)
          'org-modern-priority)))))
 
 (defun org-modern--progress ()
@@ -469,7 +468,7 @@ the font.")
              (if-let ((faces org-modern-tag-faces)
                       (face (or (cdr (assoc (buffer-substring-no-properties colon-end cbeg) faces))
                                 (cdr (assq t faces)))))
-                 `(:inherit (,face org-modern-tag))
+                 `(,face org-modern-tag)
                'org-modern-tag)))
           (add-text-properties cbeg cend colon-props)
           (setq colon-beg cbeg colon-end cend))))))
@@ -486,7 +485,7 @@ the font.")
      beg end 'face
      (if-let ((face (or (cdr (assoc todo org-modern-todo-faces))
                         (cdr (assq t org-modern-todo-faces)))))
-         `(:inherit (,face org-modern-label))
+         `(,face org-modern-label)
        (if (string-match-p org-not-done-regexp todo)
            'org-modern-todo 'org-modern-done)))))
 
